@@ -4,7 +4,6 @@
 import os
 import json
 
-
 class AppProduct:
     """
     运行环境
@@ -15,7 +14,7 @@ class AppProduct:
         环境变量
         """
         # 日志
-        self.is_debug = True
+        self.IS_DEBUG = True
         # 声明环境变量: product.json 保持一致
 
     def create():
@@ -24,15 +23,15 @@ class AppProduct:
         if "ENV" in os.environ:
             env_code = os.environ["ENV"]
         envs = {}
-        with open("package.json", "r") as file:
+        with open("product.json", "r") as file:
             envs = json.loads(file.read())["envs"]
-        env_runtime = envs[env_code]
-        # 若需要外部环境变量加载，在此进行
-        # 环境配置
-        print(env_code, json.dumps(env_runtime, indent=4))
+        runtime = envs[env_code]
+        # 环境变量
+        if "IS_DEBUG" in os.environ:
+            runtime["IS_DEBUG"] = os.environ["IS_DEBUG"]
         # 初始化配置
         prod = AppProduct()
-        prod.__dict__ = env_runtime
+        prod.__dict__ = runtime
         return prod
 
 
